<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="68px">
      <el-row :gutter="20">
        <el-col :span="6">
          <el-form-item label="料号" prop="itemNumber">
            <el-input
              v-model="queryParams.itemNumber"
              placeholder="请输入料号"
              clearable
              @keyup.enter="handleQuery"
            />
          </el-form-item>
        </el-col>
        <el-col :span="18" style="text-align: right;">
          <el-form-item>
              <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
              <el-button icon="Refresh" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-col>
      </el-row>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <HxlhTable
        style="width: 100%"
        :columns="columns"
        :data="materialStorageManagementList"
        :loading="loading"
        :height="height"
        :page="page"
        @on-checkbox="handleCheckboxChange"
        @changePageNo="changePageNo"
        @changePageSize="changePageSize"
    >
    </HxlhTable>
  </div>
</template>

<script setup name="MaterialStorageManagement">
import { listMaterialStorageManagement, getMaterialStorageManagement, delMaterialStorageManagement, addMaterialStorageManagement, updateMaterialStorageManagement } from "@/api/basicData/materialStorageManagement/materialStorageManagement";
import HxlhTable from '@/components/HxlhTable'
import { listAll_plant } from "@/api/basicData/plant";
import axios from 'axios';

const { proxy } = getCurrentInstance();
const materialStorageManagementList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const title = ref("");
const height = ref(document.documentElement.clientHeight - 230 + "px;")
const queryPlants = ref({status: 1});
const plantList = ref([]);

// 分页属性
const page = ref({
  total: 0,
  current: 1,
  size: 10
});

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    itemNumber: null,
  },
  rules: {
  }
});

// 表格配置 
const columns = ref([
  { type: 'seq', title: '序号', width: 60 },
  {
    title: '料号',
    field: 'itemNumber',
  },
  {
    title: '数量',
    field: 'num',
  },
  {
    title: '适用工厂',
    field: 'applicableFactories',
    formatter: (({ cellValue, row, column }) => {
      if (cellValue) {
        for(let i=0;i<plantList.value.length;i++){
          if(cellValue===plantList.value[i].plantCode){
            return plantList.value[i].plantName
          }
        }
      }
      return '';
    })
  },
  {
    title: '集成日期',
    field: 'integrationDate',
  },
  {
    title: '刷新日期',
    field: 'refreshDate',
  },
]);

const { queryParams, form, rules } = toRefs(data);

/** 查询物料库存管理列表 */
function getList() {
  loading.value = true;
  axios.all([
      /** 查询工厂列表 */
      listAll_plant(queryPlants.value),
      listMaterialStorageManagement(queryParams.value)
    ])
    .then(axios.spread((response1, response2) => {
      plantList.value = response1.data;
      materialStorageManagementList.value = response2.rows;
      page.value.total = response2.total;
      loading.value = false;
    }))
    .catch(error => {
      console.error('请求出错:', error);
    });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    itemNumber: null,
    num: null,
    applicableFactories: null,
    integrationDate: null,
    refreshDate: null,
    createBy: null,
    createTime: null,
    updateBy: null,
    updateTime: null
  };
  proxy.resetForm("materialStorageManagementRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加物料库存管理";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const _id = row.id || ids.value
  getMaterialStorageManagement(_id).then(response => {
    form.value = response.data;
    open.value = true;
    title.value = "修改物料库存管理";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["materialStorageManagementRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        updateMaterialStorageManagement(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addMaterialStorageManagement(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
function handleDelete(row) {
  const _ids = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除物料库存管理编号为"' + _ids + '"的数据项？').then(function() {
    return delMaterialStorageManagement(_ids);
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download('materialStorageManagement/materialStorageManagement/export', {
    ...queryParams.value
  }, `materialStorageManagement_${new Date().getTime()}.xlsx`)
}

function changePageNo(currentPage) {
  page.value.current = currentPage;
  queryParams.value.pageNum = currentPage;
  getList();
}

function changePageSize(pageSize) {
  page.value.current = 1;
  queryParams.value.pageNum = 1;
  queryParams.value.pageSize = pageSize;
  getList();
}

getList();
</script>
